==> fred-ferda-3.13.2.tar.gz: fred-ferda-3.13.2/ferda/views/ajax/keyset.py <==
"""Keyset related ajax views."""
from datetime import datetime
from typing import Dict, Optional, Union, cast
from uuid import UUID

from django.contrib.auth.mixins import LoginRequiredMixin, PermissionRequiredMixin

from ferda.backend import BACKEND
from ferda.backend.exceptions import KeysetDoesNotExist
from ferda.constants import LogEntryType

from .common import AbstractAuthInfoView, AbstractInfoView, AbstractStateHistoryView, AbstractStateView


class KeysetAuthInfoView(LoginRequiredMixin, PermissionRequiredMixin, AbstractAuthInfoView):
    """Keyset AuthInfo view."""

    permission_required = (
        'ferda.can_view_registry',
        'ferda.can_view_authinfo',
    )

    log_entry_type = LogEntryType.KEYSET_AUTH_INFO
    log_entry_reference_name = 'keyset'
    object_does_not_exist_exception = KeysetDoesNotExist

    def get_object_auth_info(self, object_id: UUID, history_id: Union[UUID, datetime] = None) -> Optional[str]:
        """Get keyset AuthInfo."""
        if isinstance(history_id, datetime):
            keyset_history = BACKEND.get_keyset_history(keyset_id=object_id, start=history_id, end=history_id)
            history_id = cast(UUID, keyset_history['timeline'][0]['keyset_history_id'])
        return BACKEND.get_keyset_info(keyset_id=object_id, history_id=history_id).get('auth_info', None)


class KeysetInfoView(LoginRequiredMixin, PermissionRequiredMixin, AbstractInfoView):
    """Keyset info view."""

    permission_required = 'ferda.can_view_registry'

    log_entry_type = LogEntryType.KEYSET_DETAIL
    log_entry_reference_name = 'keyset'
    object_does_not_exist_exception = KeysetDoesNotExist

    def get_object_info(self, object_id: UUID, history_id: Union[UUID, datetime] = None) -> dict:
        """Get keyset info."""
        if isinstance(history_id, datetime):
            keyset_history = BACKEND.get_keyset_history(keyset_id=object_id, start=history_id, end=history_id)
            history_id = cast(UUID, keyset_history['timeline'][0]['keyset_history_id'])
        return BACKEND.get_keyset_info(keyset_id=object_id, history_id=history_id)


class KeysetStateView(LoginRequiredMixin, PermissionRequiredMixin, AbstractStateView):
    """Keyset state view."""

    permission_required = 'ferda.can_view_registry'

    log_entry_type = LogEntryType.KEYSET_STATE
    log_entry_reference_name = 'keyset'
    object_does_not_exist_exception = KeysetDoesNotExist

    def get_object_state(self, object_id: UUID) -> Dict[str, bool]:
        """Get keyset state."""
        return BACKEND.get_keyset_state(keyset_id=object_id)


class KeysetStateHistoryView(LoginRequiredMixin, PermissionRequiredMixin, AbstractStateHistoryView):
    """Keyset state history view."""

    permission_required = 'ferda.can_view_registry'

    log_entry_type = LogEntryType.KEYSET_STATE
    log_entry_reference_name = 'keyset'
    object_does_not_exist_exception = KeysetDoesNotExist

    def get_object_state_history(self, object_id: UUID) -> dict:
        """Get keyset state history."""
        return BACKEND.get_keyset_state_history(keyset_id=object_id)

==> fred-ferda-3.23.0rc2.tar.gz: fred-ferda-3.23.0rc2/ferda/views/ajax/keyset.py <==
"""Keyset related ajax views."""
from datetime import datetime
from typing import Dict, Optional, Union, cast
from uuid import UUID

from django.contrib.auth.mixins import LoginRequiredMixin, PermissionRequiredMixin

from ferda.backend import BACKEND
from ferda.backend.exceptions import KeysetDoesNotExist
from ferda.constants import LogEntryType

from .common import AbstractInfoView, AbstractStateHistoryView, AbstractStateView


class KeysetInfoView(LoginRequiredMixin, PermissionRequiredMixin, AbstractInfoView):
    """Keyset info view."""

    permission_required = "ferda.can_view_registry"

    log_entry_type = LogEntryType.KEYSET_DETAIL
    log_entry_reference_name = "keyset"
    object_does_not_exist_exception = KeysetDoesNotExist

    def get_object_info(self, object_id: UUID, history_id: Optional[Union[UUID, datetime]] = None) -> dict:
        """Get keyset info."""
        if isinstance(history_id, datetime):
            keyset_history = BACKEND.get_keyset_history(keyset_id=object_id, start=history_id, end=history_id)
            history_id = cast(UUID, keyset_history["timeline"][0]["keyset_history_id"])
        return BACKEND.get_keyset_info(keyset_id=object_id, history_id=history_id)


class KeysetStateView(LoginRequiredMixin, PermissionRequiredMixin, AbstractStateView):
    """Keyset state view."""

    permission_required = "ferda.can_view_registry"

    log_entry_type = LogEntryType.KEYSET_STATE
    log_entry_reference_name = "keyset"
    object_does_not_exist_exception = KeysetDoesNotExist

    def get_object_state(self, object_id: UUID) -> Dict[str, bool]:
        """Get keyset state."""
        return BACKEND.get_keyset_state(keyset_id=object_id)


class KeysetStateHistoryView(LoginRequiredMixin, PermissionRequiredMixin, AbstractStateHistoryView):
    """Keyset state history view."""

    permission_required = "ferda.can_view_registry"

    log_entry_type = LogEntryType.KEYSET_STATE
    log_entry_reference_name = "keyset"
    object_does_not_exist_exception = KeysetDoesNotExist

    def get_object_state_history(self, object_id: UUID) -> dict:
        """Get keyset state history."""
        return BACKEND.get_keyset_state_history(keyset_id=object_id)
